@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2006           Ji YongGang <jungle@soforge.com>
+ *  Copyright (c) 2006           Ji YongGang <jungle@soforge-studio.com>
  *
  *  ChmSee is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 
 #if defined(__linux__)
 #include <fcntl.h>
-#include <openssl/md5.h>
+#include <gcrypt.h>
 #else
 #include <md5.h>
 #endif
@@ -264,22 +264,22 @@ static char *
 MD5File(const char *filename, char *buf)
 {
         unsigned char buffer[1024];
-        unsigned char digest[16];
+        unsigned char* digest;
         static const char hex[]="0123456789abcdef";
 
-        MD5_CTX ctx;
+        gcry_md_hd_t hd;
         int f, i;
 
         if(filename == NULL)
                 return NULL;
 
-        MD5_Init(&ctx);
-        f = open(filename, O_RDONLY, 0666);
+        gcry_md_open(&hd, GCRY_MD_MD5, 0);
+        f = open(filename, O_RDONLY);
         if (f < 0)
                 return NULL;
 
         while ((i = read(f, buffer, sizeof(buffer))) > 0)
-                MD5_Update(&ctx, buffer, (unsigned int)i);
+                gcry_md_write(hd, buffer, i);
 
         close(f);
 
@@ -291,7 +291,7 @@ MD5File(const char *filename, char *buf)
         if (buf == NULL)
                 return (NULL);
 
-        MD5_Final(digest, &ctx);
+        digest = (unsigned char*)gcry_md_read(hd, 0);
 
         for (i = 0; i < 16; i++) {
                 buf[i+i] = hex[(u_int32_t)digest[i] >> 4];
@@ -744,6 +744,3 @@ chmfile_new(const gchar *filename)
         
         return chmfile;
 }
-
-/* arch-tag: d710aac4-fce8-11da-92c5-00e04c516bee
-   (do not change this comment) */
