@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2006           Ji YongGang <jungle@soforge.com>
+ *  Copyright (c) 2006           Ji YongGang <jungle@soforge-studio.com>
  *
  *  ChmSee is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -195,8 +195,8 @@ destroy_cb(GtkWidget *widget, ChmSee *chmsee)
 static gboolean
 configure_event_cb(GtkWidget *widget, GdkEventConfigure *event, ChmSee *chmsee)
 {
-        if (event->width != chmsee->width 
-            || event->height != chmsee->height)
+        if (chmsee->html_notebook != NULL 
+            && (event->width != chmsee->width || event->height != chmsee->height))
                 reload_current_page(chmsee);
 
         chmsee->width = event->width;
@@ -1480,6 +1480,3 @@ chmsee_open_file(ChmSee *chmsee, const gchar *filename)
                 gtk_widget_destroy(msg_dialog);
         }
 }
-
-/* arch-tag: b8373f78-fce8-11da-92c5-00e04c516bee
-   (do not change this comment) */
