@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2006           Ji YongGang <jungle@soforge.com>
+ *  Copyright (c) 2006           Ji YongGang <jungle@soforge-studio.com>
  *
  *  ChmSee is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -50,6 +50,3 @@ void link_unref(Link *);
 
 #endif /* __LINK_H__ */
 
-
-/* arch-tag: 9406333e-162e-11db-bd24-00e04c516bee
-   (do not change this comment) */
