@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2006           Ji YongGang <jungle@soforge.com>
+ *  Copyright (c) 2006           Ji YongGang <jungle@soforge-studio.com>
  *
  *  ChmSee is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ static void
 display_version(int exitflag)
 {
         printf("ChmSee %s\n\n", PACKAGE_VERSION);
-        printf("Copyright (C) 2006  Ji YongGang <jungle@soforge.com>\n");
+        printf("Copyright (C) 2006  Ji YongGang <jungle@soforge-studio.com>\n");
         printf("This is free software; see the source for copying conditions. There is NO\n");
         printf("warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\n");
 
@@ -70,7 +70,7 @@ display_usage(int exitflag)
         printf("\nOptions:\n");
         printf("  -h, --help                display this help and exit\n");
         printf("  -V, --version             print version information and exit\n");
-        printf("\nReport bugs to jungle@soforge.com\n");
+        printf("\nReport bugs to jungle@soforge-studio.com\n");
 
         if (exitflag)
                 exit(exitflag - 1); 
@@ -137,6 +137,3 @@ main(int argc, char *argv[])
 
         return 0;
 }
-
-/* arch-tag: 8cb052c2-fce8-11da-92c5-00e04c516bee
-   (do not change this comment) */
