@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2006		 Ji YongGang <jungle@soforge.com>
+ *  Copyright (c) 2006		 Ji YongGang <jungle@soforge-studio.com>
  *
  *  ChmSee is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -170,6 +170,3 @@ setup_window_new(ChmSee *chmsee)
 
 	g_object_unref(glade);
 }
-
-/* arch-tag: 2764f67e-fce9-11da-92c5-00e04c516bee
-   (do not change this comment) */
