@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2006           Ji YongGang <jungle@soforge.com>
+ *  Copyright (c) 2006           Ji YongGang <jungle@soforge-studio.com>
  *
  *  ChmSee is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -626,6 +626,3 @@ get_real_uri(const gchar *uri)
 
         return real_uri;
 }
-
-/* arch-tag: 43499a48-fce9-11da-92c5-00e04c516bee
-   (do not change this comment) */
